@@ -1,6 +1,6 @@
 # Copyright (C) 2003-2008 by Dr. Dieter Maurer, Illtalstr. 25, D-66571 Bubach, Germany
 # see "LICENSE.txt" for details
-#       $Id: ManagableIndex.py,v 1.1.1.1 2008/06/28 16:03:50 dieter Exp $
+#       $Id: ManagableIndex.py,v 1.3 2009/07/08 12:00:10 dieter Exp $
 '''Managable Index abstract base class.'''
 
 import copy
@@ -129,8 +129,10 @@ class ManagableIndex(OFolder,Normalize, Ignore):
       for k in values.keys():
         if k not in allowed: raise ValueError('not a known property: %s' % k)
       obj.manage_changeProperties(**values)
-    if extra: setProperties(self, extra, ('ValueProviders',))
-    providers = extra and extra.get('ValueProviders')
+    if extra:
+      setProperties(self, extra, ('ValueProviders',))
+      providers = extra.get('ValueProviders')
+    else: providers = None
     if providers is None: self._createDefaultValueProvider()
     else:
       for p in providers:
